@@ -5,7 +5,7 @@
 # License: GPL V2
 #
 # thomas@linuxmuster.net
-# 20200203
+# 20200218
 #
 
 # If you don't have a "standalone shell" busybox, enable this:
@@ -618,10 +618,9 @@ network(){
   if [ -s /start.conf ]; then
    echo "Network connection to $server established successfully."
    grep ^[a-z] /tmp/dhcp.log | sed -e 's|^|local |g' > /tmp/network.ok
-   echo "Syncing time ..."
-   ntpd -n -q -p "$server" &> /dev/null
-   hwclock --systohc &> /dev/null
-   date
+   echo "Starting time sync ..."
+   ( ntpd -n -q -p "$server" && hwclock --systohc ) &
+   #date
    # linbo update & grub installation
    do_linbo_update "$server"
    # also look for other needed files
